"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const template_html_1 = require("./template.html");
// The module 'vscode' contains the VS Code extensibility API
// Import the module and reference it with the alias vscode in your code below
const vscode = require("vscode");
const issueProvider_1 = require("./issueProvider");
const configurationProvider_1 = require("./configurationProvider");
// this method is called when your extension is activated
// your extension is activated the very first time the command is executed
function activate(context) {
    const issueProvider = new issueProvider_1.IssueProvider();
    // Use the console to output diagnostic information (console.log) and errors (console.error)
    // This line of code will only be executed once when your extension is activated
    let disposable = vscode.commands.registerCommand('giteaIssues.initRepo', () => __awaiter(this, void 0, void 0, function* () {
        if (vscode.workspace.rootPath === undefined) {
            return vscode.window.showErrorMessage("No project opened!");
        }
        let Token, Domain, Owner, Name;
        yield vscode.window.showInputBox({
            placeHolder: "Enter your gitea token here",
        }).then(token => {
            Token = token === undefined ? "" : token;
        });
        yield vscode.window.showInputBox({
            placeHolder: "Domain from your gitea server without 'https://'",
        }).then(domain => {
            Domain = domain === undefined ? "" : domain;
        });
        yield vscode.window.showInputBox({
            placeHolder: "Repository Owner",
        }).then(owner => {
            Owner = owner === undefined ? "" : owner;
        });
        yield vscode.window.showInputBox({
            placeHolder: "Repository Name",
        }).then(name => {
            Name = name === undefined ? "" : name;
        });
        const repoInfo = {
            token: Token,
            domain: Domain,
            repo_owner: Owner,
            repo_name: Name,
        };
        const rpim = new configurationProvider_1.RepositoryInformationManager();
        rpim.saveRepoInformation(vscode.workspace.rootPath, repoInfo);
    }));
    context.subscriptions.push(disposable);
    vscode.window.registerTreeDataProvider('open-issues', issueProvider);
    vscode.commands.registerCommand('giteaIssues.openIssue', (issue) => {
        const panel = vscode.window.createWebviewPanel('issue', issue.label, vscode.ViewColumn.Active, {});
        panel.webview.html = template_html_1.html(issue);
    });
    vscode.commands.registerCommand('giteaIssues.refreshIssues', () => {
        issueProvider.refresh();
    });
    // The command has been defined in the package.json file
    // Now provide the implementation of the command with registerCommand
    // The commandId parameter must match the command field in package.json
}
exports.activate = activate;
// this method is called when your extension is deactivated
function deactivate() { }
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map